# IFFPred collection

## General information

Data Set Title: "IFFPred collection: Intraoperative Femur Fracture Prediction collection".

Data Set Authors:

  - Maila Petrucci (Dipartimento di Ingegneria Industriale, Alma Mater Studiorum - University of Bologna), ORCID 0000-0001-7813-8809; 
  - Antonino Amedeo La Mattina (Laboratorio di Tecnologia Medica, IRCCS Istituto Ortopedico Rizzoli), ORCID 0000-0002-9927-2393; 
  - Cristina Curreli (Laboratorio di Tecnologia Medica, IRCCS Istituto Ortopedico Rizzoli), ORCID 0000-0002-9904-3849; 
  - Enrico Tassinari (Ortopedia-Traumatologia e Chirurgia protesica e dei reimpianti d'anca e di ginocchio, IRCCS Istituto Ortopedico Rizzoli), ORCID 0000-0003-4556-4734;
  - Marco Viceconti (Dipartimento di Ingegneria Industriale, Alma Mater Studiorum - University of Bologna), ORCID 0000-0002-2293-1530.

Data Set Contact Person: Antonino Amedeo La Mattina (Laboratorio di Tecnologia Medica, IRCCS Istituto Ortopedico Rizzoli), ORCID 0000-0002-9927-2393, [antoninoamedeo.lamattina@ior.it](mailto:antoninoamedeo.lamattina@ior.it)

Data Set License: The provided data are provided under the Creative Commons Attribution 4.0 International License (CC BY 4.0). To view a copy of this license, visit [https://creativecommons.org/licenses/by/4.0/](https://creativecommons.org/licenses/by/4.0/) or send a letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.

Publication Year: 2024.

Project Info: In Silico World (Lowering barriers to ubiquitous adoption of In Silico Trials), funded by European Commission, Horizon 2020 Programme. Grant Agreement num. 101016503; [https://insilico.world/](https://insilico.world/).


## Dataset description

The IFFPred collection dataset is composed of 11 anonymized masked and processed CT scans of whole femurs, the corresponding segmentations, the stem and rasp geometries in the pose selected by a surgeon, and the coordinates of reference points used in the simulations.
One folder for each subject is available: `PXX_Y`, where _XX_ is the patient code (from `01` to `11`) and _Y_ is the modelled side (`L` for left, `R` for right).
The file `PXX_Y\PXX_Y.nrrd` contains the monolateral masked processed CT scan; the voxels included in the segmentation contain the elastic modulus of the voxels, while the other voxels are set to 0.
The bone segmentation is contained in the file `PXX_Y\PXX_Bone.stl`.
The stem and rasp geometries are contained in the files `PXX_Y\PXX_Stem.stl` and `PXX_Y\PXX_Rasp.stl`, respectively.
The coordinates of the points necessary for the definition of the simulation reference system are reported in the file `PXX_Y\PXX_Landmarks.txt`, namely: Load application point (origin), Stem Apex (X axis direction), Anteroposterior direction (Y axis direction, to be orthogonalised).

The original CT scans were collected at Rizzoli Orthopaedic Institute (IOR) from 1999 to 2016 for surgical planning of hip arthroplasty at the contralateral femur.
The patients CT scans were selected within deceased patients for extreme values in terms of the four most important determinants for bone strength as age, gender, size (estimated with the femoral biomechanical length), and degree of osteoporosis.
All the necessary Ethical committee authorisation documents have been obtained and are available (in Italian) upon request.


### Data management and workflow

The original CT scans were interpolated using Matlab (release R2019b, The Mathworks Inc) in order to have uniform spacing between slices and were successively anonymised using Synedra View Personal (version 19.0.0.3, Synedra Information Technologies GmbH); eventually, residual identifying fields in the DICOM files were removed or overwritten with a custom Matlab script.
As a result, in the date fields, the only reliable information was the year, while months and days were set to the 1st of July for all the records.
Also, all the time fields of the study were set to 15:00:00.
Subsequently, the CT scans were segmented from the CT scan by thresholding at HU = 200 using 3D Slicer (v. 4.10.2).
The final segmentations were exported as STL files.
CT scans were masked, cropped and exported in NRRD file format with 3D Slicer, and processed (conversion from HU to Young modulus of the segmented bone voxels) with a custom Python script.


### Data formats 

For each subject the following data are given, using the specified formats:

  - Masked and processed monolateral CT scans: NRRD files (`PXX_Y\PXX_Y.nrrd`) containing the volume of the modelled femur (right, R, or left, L)
  - Femur segmentation: binary STL file (`PXX_Y\PXX_Bone.stl`) 
  - Stem and rasp geometries: binary STL files (`PXX_Y\PXX_Stem.stl` and `PXX_Y\PXX_Rasp.stl`, respectively)
  - Points for simulation reference system: TXT file (`PXX_Y\PXX_Landmarks.txt`) with the X, Y, and Z coordinates of the landmarks in the CT reference system.


## Licensing 

This work is licensed under the Creative Commons Attribution 4.0 International License. To view a copy of this license, visit [https://creativecommons.org/licenses/by/4.0/](https://creativecommons.org/licenses/by/4.0/) or send a letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.
